@@ -1,7 +1,5 @@
 use crate::time;
 use std::fmt::{self, Display};
-use std::num::ParseIntError;
-use std::str::FromStr;
 use syn::parse::{Error, Parse, ParseStream};
 use syn::{LitInt, Token};
 
@@ -22,29 +20,6 @@ impl Display for Date {
     }
 }
 
-pub struct ParseDateError;
-
-impl From<ParseIntError> for ParseDateError {
-    fn from(_err: ParseIntError) -> Self {
-        ParseDateError
-    }
-}
-
-impl FromStr for Date {
-    type Err = ParseDateError;
-
-    fn from_str(s: &str) -> Result<Self, Self::Err> {
-        let mut date = s.split('-');
-        let year = date.next().ok_or(ParseDateError)?.parse()?;
-        let month = date.next().ok_or(ParseDateError)?.parse()?;
-        let day = date.next().ok_or(ParseDateError)?.parse()?;
-        match date.next() {
-            None => Ok(Date { year, month, day }),
-            Some(_) => Err(ParseDateError),
-        }
-    }
-}
-
 impl Parse for Date {
     fn parse(input: ParseStream) -> syn::Result<Self> {
         let span = input.cursor().token_stream();
